@@ -8,7 +8,9 @@ var searchData=
   ['option_20and_20symbols_5',['Example: layout, option and symbols',['../rule-file-format.html#rules-options-example',1,'']]],
   ['options_6',['options',['../rule-file-format.html#rules-layout-specific-options-example',1,'Example: layout-specific options'],['../structxkb__rule__names.html#a556899eafb333c440be64ede408644df',1,'xkb_rule_names::options']]],
   ['or_20lock_7',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
-  ['overflow_8',['XKB-052 – Integer overflow',['../error-index.html#XKB-052',1,'']]],
-  ['overriding_20the_20system_20sections_9',['Overriding the system sections',['../user-configuration.html#overriding-the-system-sections',1,'']]],
-  ['overview_10',['Overview',['../group__compose.html',1,'Overview'],['../group__x11.html',1,'Overview']]]
+  ['or_20propose_20a_20patch_8',['Where are the standard keyboard layouts designed?&lt;br  /&gt;
+How to report an issue or propose a patch?',['../faq.html#where-are-the-standard-keyboard-layouts-designedbrhow-to-report-an-issue-or-propose-a-patch',1,'']]],
+  ['overflow_9',['XKB-052 – Integer overflow',['../error-index.html#XKB-052',1,'']]],
+  ['overriding_20the_20system_20sections_10',['Overriding the system sections',['../user-configuration.html#overriding-the-system-sections',1,'']]],
+  ['overview_11',['Overview',['../group__compose.html',1,'Overview'],['../group__x11.html',1,'Overview']]]
 ];
